---
name: Question/Support/Other
about: If you have a usage question
labels: question
# This template is based on the scikit-learn template
# https://github.com/scikit-learn/scikit-learn/blob/8e61534f1087703f476414d8dbd3688282f8eebf/.github/ISSUE_TEMPLATE/usage_question.md
---


If you have a question on how to use this library please submit it to https://discourse.matplotlib.org/c/3rdparty/18
instead of as a Github issue. This makes it easier to keep track of issues for development. Plus, ff you ask on discourse
your question will be seen by more people so you'll probably get an answer faster (and maybe even a better answer).

Thanks for understanding!
